function [X,y]=mixt_model(m,S,P,N,sed)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% FUNCTION
%   [X,y]=mixt_model(m,S,P,N,sed)
% This function generates a set X of l-dimensional points that stem from 
% a (mixtured) pdf that is a weighted sum of c normal distributions.
%
% INPUT ARGUMENTS:
%   m:      an lxc dimensional matrix whose j-th column contains the
%           (l-dimensional) mean of the j-th normal distribution.
%   S:      an lxlxc dimensional matrix whose j-th lxl two-dimensional
%           "slice" is the covariance matrix corresponding to the j-th 
%           normal distribution.
%   P:      an c-dimensional vector whose j-th coordinate contains 
%           the a priori probability for the j-th normal distribution.
%   N:      the total number of points to be generated by the mixture
%           distribution.
%   sed:    the seed used for the initialization of the built-in MATLAB
%           random generator function "rand".
% OUTPUT ARGUMENTS:
%   X:      an lxN dimensional matrix whose columns contain the data
%           points.
%   y:      an N-dimensional vector whose i-th element contains the label
%           of the distribution that generated the i-th vector.
%
% (c) 2008 A. Pikrakis, S. Theodoridis, K. Koutroumbas, D. Cavouras
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    rand('seed',sed)
    [l,c]=size(m);
    
    %Constructing the P_acc vector. This is necessary for picking randomly
    %one of the c normal distributions in order to generate a point.
    P_acc=P(1);
    for i=2:c
        t=P_acc(i-1)+P(i);
        P_acc=[P_acc t];
    end
    
    % Generation of the data set
    X=[];
    y=[];
    for i=1:N
        t=rand;
        ind=sum(t>P_acc)+1;  % Index of the normal distribution that will generate the i-th vector
        X=[X; mvnrnd(m(:,ind)',S(:,:,ind),1)];
        y=[y ind];
    end
    X=X';